@@ -129,7 +129,6 @@
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
- *
  */
 #include "tclInt.h"
 
@@ -2300,7 +2299,7 @@ MODULE_SCOPE int yynerrs;
  * Month and day table.
  */
 
-static TABLE MonthDayTable[] = {
+static const TABLE MonthDayTable[] = {
     { "january",	tMONTH,	 1 },
     { "february",	tMONTH,	 2 },
     { "march",		tMONTH,	 3 },
@@ -2332,7 +2331,7 @@ static TABLE MonthDayTable[] = {
  * Time units table.
  */
 
-static TABLE UnitsTable[] = {
+static const TABLE UnitsTable[] = {
     { "year",		tMONTH_UNIT,	12 },
     { "month",		tMONTH_UNIT,	 1 },
     { "fortnight",	tDAY_UNIT,	14 },
@@ -2350,7 +2349,7 @@ static TABLE UnitsTable[] = {
  * Assorted relative-time words.
  */
 
-static TABLE OtherTable[] = {
+static const TABLE OtherTable[] = {
     { "tomorrow",	tDAY_UNIT,	1 },
     { "yesterday",	tDAY_UNIT,	-1 },
     { "today",		tDAY_UNIT,	0 },
@@ -2383,7 +2382,7 @@ static TABLE OtherTable[] = {
  * point constants to work around an SGI compiler bug).
  */
 
-static TABLE TimezoneTable[] = {
+static const TABLE TimezoneTable[] = {
     { "gmt",	tZONE,	   HOUR( 0) },	    /* Greenwich Mean */
     { "ut",	tZONE,	   HOUR( 0) },	    /* Universal (Coordinated) */
     { "utc",	tZONE,	   HOUR( 0) },
@@ -2468,7 +2467,7 @@ static TABLE TimezoneTable[] = {
  * Military timezone table.
  */
 
-static TABLE	MilitaryTable[] = {
+static const TABLE MilitaryTable[] = {
     { "a",	tZONE,	-HOUR( 1) },
     { "b",	tZONE,	-HOUR( 2) },
     { "c",	tZONE,	-HOUR( 3) },
@@ -2561,7 +2560,7 @@ LookupWord(
 {
     register char *p;
     register char *q;
-    register TABLE *tp;
+    register const TABLE *tp;
     int i, abbrev;
 
     /*
